@@ -1,11 +1,9 @@
-#[cfg(feature = "async")]
-mod async_code;
-#[cfg(feature = "async")]
-pub use async_code::*;
-
 mod application;
 pub use application::*;
 
+mod channel_dispatcher;
+pub use channel_dispatcher::*;
+
 mod drawing_context;
 pub use drawing_context::*;
 
